/*******************************************************************************
* File Name: main.c
*
* Version: 1.0
*
* Description:
* Messung der Vorlauf- und Rücklaufleistung an einem SWR- Messkopf im Kurzwellenbereich

* Hardware Connections:
* Vorlauf (Ausgang des AD8307) - Pin_1 - P4(2) High Impedance Analog
* Rücklauf       =     =       - Pin_3 - P4(1)   =
* Drehgeber A                  - Pin_5 - P5(6) Resistive Pull Up
*           B                  - Pin_6 - P5(7)   =
* Piezo- Summer                - Pin_2 - P5(3) Strong Drive
* LCD 4* 20 Zeichen            -       - P6(6:0)
* AD9850 Steuerung:           - F_Data - P3(0)Strong Drive
* AD9850 Takt                  - W_CLK - P3(1)Strong Drive
* AD9850 FQ (Quittung)         - FQ    - P3(2)Strong Drive
* AD9850 Reset                 - Reset - P3(3)Strong Drive
* Taste 1                      - BTN_1 - P3(4) Resistive Pull Up
* Taste 2                      - BTN_2 - P3(5) Resistive Pull Up
* Taste 3                      - BTN_3 - P3(6) Resistive Pull Up
* Taste 4                      - BTN_4 - P3(7) Resistive Pull Up
*
*******************************************************************************/

#include <device.h>
#include <fastmath.h>

#define pulsetime 15

char8 resultStr[16u];
uint8 Button;
//Konstanten für horizontales Balkendiagramm (custom fonts)
uint8 const CYCODE LCD_customFontsH[] = \
{
    /* Character LCD_CUSTOM_0   */
    0x00u,    0x00u,    0x00u,    0x00u,    0x00u,    0x00u,    0x00u,    0x00u, \
    /* Character LCD_CUSTOM_1   */
    0x10u,    0x10u,    0x10u,    0x10u,    0x10u,    0x10u,    0x10u,    0x10u, \
    /* Character LCD_CUSTOM_2   */
    0x18u,    0x18u,    0x18u,    0x18u,    0x18u,    0x18u,    0x18u,    0x18u, \
    /* Character LCD_CUSTOM_3   */
    0x1Cu,    0x1Cu,    0x1Cu,    0x1Cu,    0x1Cu,    0x1Cu,    0x1Cu,    0x1Cu, \
    /* Character LCD_CUSTOM_4   */
    0x1Eu,    0x1Eu,    0x1Eu,    0x1Eu,    0x1Eu,    0x1Eu,    0x1Eu,    0x1Eu, \
    /* Character LCD_CUSTOM_5   */
    0x1Fu,    0x1Fu,    0x1Fu,    0x1Fu,    0x1Fu,    0x1Fu,    0x1Fu,    0x1Fu, \
    /* Character LCD_CUSTOM_6   */
    0x00u,    0x00u,    0x00u,    0x00u,    0x00u,    0x00u,    0x00u,    0x00u, \
    /* Character LCD_CUSTOM_7   */
    0x00u,    0x00u,    0x00u,    0x00u,    0x00u,    0x00u,    0x00u,    0x00u \
};


//Konstanten für vertikales Balkendiagramm (custom fonts)
uint8 const CYCODE LCD_customFontsV[] = \
{
    /* Character LCD_CUSTOM_0   */
    0x00u,    0x00u,    0x00u,    0x00u,    0x00u,    0x00u,    0x00u,    0x1Fu, \
    /* Character LCD_CUSTOM_1   */
    0x00u,    0x00u,    0x00u,    0x00u,    0x00u,    0x00u,    0x1Fu,    0x1Fu, \
    /* Character LCD_CUSTOM_2   */
    0x00u,    0x00u,    0x00u,    0x00u,    0x00u,    0x1Fu,    0x1Fu,    0x1Fu, \
    /* Character LCD_CUSTOM_3   */
    0x00u,    0x00u,    0x00u,    0x00u,    0x1Fu,    0x1Fu,    0x1Fu,    0x1Fu, \
    /* Character LCD_CUSTOM_4   */
    0x00u,    0x00u,    0x00u,    0x1Fu,    0x1Fu,    0x1Fu,    0x1Fu,    0x1Fu, \
    /* Character LCD_CUSTOM_5   */
    0x00u,    0x00u,    0x1Fu,    0x1Fu,    0x1Fu,    0x1Fu,    0x1Fu,    0x1Fu, \
    /* Character LCD_CUSTOM_6   */
    0x00u,    0x1Fu,    0x1Fu,    0x1Fu,    0x1Fu,    0x1Fu,    0x1Fu,    0x1Fu, \
    /* Character LCD_CUSTOM_7   */
    0x1Fu,    0x1Fu,    0x1Fu,    0x1Fu,    0x1Fu,    0x1Fu,    0x1Fu,    0x1Fu \
};

  void LCD_DrawVerticalBG(uint8 row, uint8 column, uint8 maxCharacters, uint8 value) \
                                                            
    {
        /* 8-bit Counter */
        uint8 count8 = 0u;
        /* Current Row Tracker */
        int8 currentRow;
        uint8 fullChars;
        uint8 remainingPixels;

        /* Number of full characters to draw */
        fullChars = value / LCD_CHARACTER_HEIGHT;

        /* Number of remaining pixels to draw */
        remainingPixels = value % LCD_CHARACTER_HEIGHT;

        /* Put Cursor at start position */
        LCD_Position(row, column);

        /* Make sure the bar graph fits inside the space allotted */
        if(fullChars >= maxCharacters)
        {
            fullChars = maxCharacters;
        }

        /*  Write full characters */
        while(count8 < fullChars)
        {
            LCD_WriteData(LCD_CUSTOM_7);

            count8++;

            /* Each pass through, move one row higher */
            if((((int8) row) - ((int8) count8)) >= 0)
            {
                LCD_Position(row - count8, column);
            }
            else
            {
                break;
            }
        }

        if(((((int8) row) - ((int8) count8)) >= 0) && (fullChars < maxCharacters))
        {
            /* Write remaining pixels */
            if(remainingPixels == 0u)
            {
                LCD_WriteData((uint8) ' ');
            }
            else
            {
                LCD_WriteData(remainingPixels - 1u);
            }

            currentRow = ((int8) row) - ((int8) count8) - 1;

            if(currentRow >= 0)
            {
                /* Move up one row and fill with whitespace till top of bar graph */
                for(count8 = 0u; count8 < (maxCharacters - fullChars - 1u); count8++)
                {
                    LCD_Position((uint8)currentRow, column);
                    LCD_WriteData((uint8) ' ');
                    currentRow --;
                }
            }
        }
    }



CY_ISR(Int_PB1){// **** Interruptbehandlong der Tasten ***
Button|=1;}// Bit setzen

CY_ISR(Int_PB2){
Button|=2;}

CY_ISR(Int_PB3){
Button|=4;}

CY_ISR(Int_PB4){
Button|=8;}


void PulseAD9850(uint8 puls){// Steuerimpuls für DDS- Baustein
uint8	bits;

bits=Control_Reg_1_Read();
Control_Reg_1_Write(bits|puls);
CyDelayUs(pulsetime);
Control_Reg_1_Write(bits);
CyDelayUs(pulsetime);
}

void AD9850_Init(void){// DDS- Baustein initialisieren
Control_Reg_1_Write(0);
PulseAD9850(8);//Reset
PulseAD9850(2);//Clock
PulseAD9850(4);//Seriellen Modus einschalten
}

void ComAD9850(uint32 factor, uint8 phase){// Steuerwort an DDS- Baustein senden
uint8 shift;
uint8 dat1=0;


for(shift=0;shift<32;shift++){
	Control_Reg_1_Write(1&factor);
	PulseAD9850(2);//Clock
	factor=factor>>1;
}
for(shift=0;shift<8;shift++){
	Control_Reg_1_Write(1&phase);
	PulseAD9850(2);//Clock
	phase=phase>>1;
	}
PulseAD9850(4);//FQ Frequenzwort komplett
}	

void SetFrequency(double frequenz){ //Frequenz an DDS- Baustein ausgeben
 ComAD9850((uint32)((34358518.983)*frequenz),0);//2^^32/125 * Korrekturwert
}

void PreparePowerPrnt(double inpower, uint8 sel){//Hilfsroutine für Power- Anzeige
if(inpower<0.01){
	sprintf((char*)resultStr,"% 1.2f mW   ",1000*inpower);
	if(sel)LCD_DrawHorizontalBG(0, 0, 20, (uint8)(inpower*8000));//10mW Maximum
	}
else if(inpower<0.1){
	sprintf((char*)resultStr,"% 1.1f mW   ",1000*inpower);
	if(sel)LCD_DrawHorizontalBG(0, 0, 20, (uint8)(inpower*800));//100mW Maximum
	}
else if(inpower<1){
	sprintf((char*)resultStr,"% 1.0f mW   ",1000*inpower);
	if(sel)LCD_DrawHorizontalBG(0, 0, 20, (uint8)(inpower*80));//1000mW Maximum
	}
else if(inpower<10){
	if(sel)LCD_DrawHorizontalBG(0, 0, 20, (uint8)(inpower*8));//10W Maximum
	sprintf((char*)resultStr,"% 1.2f W   ",inpower);

	}
else if(inpower<100){
	if(sel)LCD_DrawHorizontalBG(0, 0, 20, (uint8)(inpower*0.8));//100W Maximum
	sprintf((char*)resultStr,"% 1.1f W   ",inpower);
	}
else{
	sprintf((char*)resultStr,"% 1.0f W   ",inpower);
	if(sel)LCD_DrawHorizontalBG(0, 0, 20, (uint8)(inpower*0.08));//1000W Maximum
	}		
}

uint8  Menu=0;
uint32 output;
uint32 null1;
uint32 Nullwert=0;
uint32 RefWert=1023;
float GrundForw=0.136;//Exemplarabhängig
float GrundRefl=0.217;// Exemplarabhängig
long	Ref1024=1;
uint32 quer0=0;
uint32 quer1=0;
uint32 quer2=0;
uint32 quer3=0;
uint32 peak1=0;
uint32 peak2=0;
uint8  startup=1;	
uint32 ring2[20]={0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
uint32 ring3[20]={0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0};
uint8 loop1=0;
double float1;
double power=0;
double powerPeak=0;
double powerRefl=0;
double powerReflPeak=0;
uint8 time;
uint8 time1;
double VSWR=1;

void ComputePower_SWR(uint8 SelPeak, uint8 SelHorBG){//Vorlauf; Rücklauf ermitteln, VSWR berechnen
uint8 index;

	AMux_1_Select(1);//*** AD 8307 Vorlauf ***
	ADC_DelSig_1_StartConvert();
	while(!ADC_DelSig_1_IsEndConversion(ADC_DelSig_1_RETURN_STATUS))
	{}
	ADC_DelSig_1_StopConvert();
    output = ADC_DelSig_1_GetResult32()-Nullwert;
	
	ring2[loop1]=output;// Mittelwert bilden
	if (startup==1) quer2=20*output;
	else{
		quer2=0;
		for(index=0; index<20;index++){//Gleitender Mittelwert
			quer2 +=ring2[index];
		}
	}
	float1=ADC_DelSig_1_CountsTo_Volts(quer2/20);
	float1*=Ref1024;
	//sprintf((char*)resultStr,"% 1.3f",float1-GrundForw);// Spannung aufbereiten	
//	power=104*pow(10,((float1-2.290)/0.330))-0.000025;//Mittl. Leistung berechnen
	power=104*exp10((float1-2.290)/0.330)-0.000025;//Mittl. Leistung berechnen
	if(power<0)power=0;
	if(SelHorBG) 	
		PreparePowerPrnt(power,1);// mit Balkengrafik
	else
		PreparePowerPrnt(power,0);// ohne Balkengrafik
	if(Menu==0){
		LCD_Position(1u, 3u);
    	LCD_PrintString(resultStr);//Mittl. Leistung anzeigen	
	}
	if(peak2<output) {//Spitzenwert ermitteln
		peak2=output;
		time=0;//Delay starten
	}
	else{
		time++;
		if(time>200) peak2=8*peak2/9;//ca. 3 Sekunden
		if(time>250) time=0;
	}
	if(Menu==0)
		PreparePowerPrnt(peak2,0);//ohne Balkengrafik
	if(SelPeak){
		
		float1=ADC_DelSig_1_CountsTo_Volts(peak2);
		float1*=Ref1024;
		//powerPeak=104*pow(10,((float1-2.290)/0.330))-0.000025;
		powerPeak=104*exp10((float1-2.290)/0.330)-0.000025;
		if(powerPeak<0)powerPeak=0;
		PreparePowerPrnt(powerPeak,0);//ohne Balkengrafik	
		LCD_Position(1u, 9u);
	    LCD_PrintString(resultStr);//Peak anzeigen		
	
	}
	//  *************          ******************         ***********
	AMux_1_Select(2);//*** AD8307 Ruecklauf- Spannung ***
	ADC_DelSig_1_StartConvert();
	if(Menu==0) {
		LCD_Position(3u, 0u);
		LCD_PrintString("SWR ");
		LCD_Position(2u, 3u);
	}
	while(!ADC_DelSig_1_IsEndConversion(ADC_DelSig_1_RETURN_STATUS))
	{}
	ADC_DelSig_1_StopConvert();
    output = ADC_DelSig_1_GetResult32()-Nullwert;

	ring3[loop1]=output;
	if (startup==1) quer3=20*output;
	else {
		quer3=0;
		for(index=0; index<20;index++){
			quer3 +=ring3[index];
		}
	}
	float1=ADC_DelSig_1_CountsTo_Volts(quer3/20);
	float1*=Ref1024;
	if(Menu==0){				
	//	LCD_Position(2u, 3u);
	//	sprintf((char*)resultStr,"% 1.3f",float1-GrundRefl);
	}	
	//powerRefl=104*pow(10,((float1-2.371)/0.330))-0.000025;//2367
	powerRefl=104*exp10((float1-2.371)/0.330)-0.000025;//2367
	if(powerRefl<0)powerRefl=0;
    //LCD_PrintString(resultStr);//Spannung anzeigen	
	
	if(Menu==0){			
		PreparePowerPrnt(powerRefl,0);	
		LCD_Position(2u, 3u);
	    LCD_PrintString(resultStr);
	}
	if(SelPeak){				
		if(peak1<output) {//Spitzenwert ermitteln
			peak1=output;
			time1=0;//Delay starten
			}
		else{
			time1++;
			if(time1>200) peak1=8*peak1/9;//ca. 3 Sekunden
			if(time1>250) time1=0;
		}
		float1=ADC_DelSig_1_CountsTo_Volts(peak1);
		float1*=Ref1024;
		sprintf((char*)resultStr,"% 1.3f",float1-GrundRefl);	
		//powerReflPeak=104*pow(10,((float1-2.367)/0.330))-0.000025;	
		powerReflPeak=104*exp10((float1-2.367)/0.330)-0.000025;	
		if(powerReflPeak<0)powerReflPeak=0;
		PreparePowerPrnt(powerReflPeak,0);
		LCD_Position(2u, 9u);
	    LCD_PrintString(resultStr);
	
	//*********** VSWR berechnen ******************
	LCD_Position(3u, 3u);	
	}
	if(powerRefl>power)powerRefl=power;
	//if(power==0)VSWR=-1;//SWR ungültig
	//else
	VSWR=(1+powerRefl/power)/(1-powerRefl/power);
	//VSWR=(1+powerReflPeak/powerPeak)/(1-powerReflPeak/powerPeak);
}


//double pow(double x,double y);
/*******************************************************************************
* Function Name: main
*
*******************************************************************************/
void main()
{

uint32 wert1;
uint8 index;
uint8 selektor;
int16 encoder=0;
int16 encoderOld=0;
int16 diff=0;
uint8  MenuOld=0;
uint8  normieren=1;//erst normieren, dann anzeigen
double freq=29.0;//AD9850 Startfrequenz
double step;//Frequenzschrittweite
uint8 i;
double sweepstep=0.2;//0.05 0.02
double loga;
double Vmin=0;
double Vmax=0;
double faktor;//Faktor für Anzeige
uint16 count;//Durchlaufzähler für Menu2
	
    /* Start the components */

    LCD_Start();
    ADC_DelSig_1_Start();
	Timer_1_Start();
	AMux_1_Start();
	PGA_1_Start();
	QuadDec_1_Start() ;
	QuadDec_1_SetCounter(0);
	
	AD9850_Init();
	isr_PB1_StartEx(Int_PB1);
	isr_PB2_StartEx(Int_PB2);
	isr_PB3_StartEx(Int_PB3);
	isr_PB4_StartEx(Int_PB4);
	
	CyGlobalIntEnable;
   
	Timer_1_WritePeriod(6);//unhörbar
	loop1=0;
	step=0.001;
	SetFrequency(freq);//3663 kHz, Phase=0
    for(;;)//Hauptschleife
    {		
		if(Button&1){//Abfrage der Taster
			Button=0;
			step=0.001;
			Menu+=1;
			if(Menu==3) Menu=0;	
		}
		else if(Button&2){
			Button=0;
			step=1.0;
		}
		else if(Button&4){
			Button=0;
			step=0.1;
		}
		else if(Button&8){
			Button=0;
			step=0.01;
		}
		if(Menu!=MenuOld){
			MenuOld=Menu;
			LCD_WriteControl(LCD_CLEAR_DISPLAY);
			SetFrequency(freq);
			
			if(Menu==2){
				LCD_LoadCustomFonts(LCD_customFontsV);//Vertikales Diagramm vorbereiten
				LCD_PrintString("VSWR");
				count=0;
				normieren=1;
			}
			else if(Menu==0){
				LCD_LoadCustomFonts(LCD_customFontsH);//Horizontales Diagramm vorbereiten
			}
		}
		encoder=(int16)QuadDec_1_GetCounter();	
		if(encoder!=encoderOld){//Abfrage Dreh- Encoder
			diff=encoder-encoderOld;
			if(diff>100)diff=1;
			if(diff<-100)diff=-1;
			freq+=step*diff;
			if(freq>40.001)freq=40;
			if(freq<0.1)freq=0.1;
			SetFrequency(freq);
			encoderOld=encoder;			
		}
	if(Menu==1){
		LCD_Position(0u, 0u);
		if(step==0.001){
		LCD_PrintString(" I                  "); 
		}
		else if(step==1.0){
		LCD_PrintString("      I             "); 
		
		}
		else if(step==0.1){
		LCD_PrintString("           I        "); 
		
		}
		else
		LCD_PrintString("                 I  "); 
		
		LCD_Position(03,9u);
		sprintf((char*)resultStr,"% 1.3f MHz ",freq);
        LCD_PrintString(resultStr);
		
		
		LCD_Position(1u, 0u);
        LCD_PrintString("kHz/M MHz  100k  10k");
		LCD_Position(03,9u);
		sprintf((char*)resultStr,"% 1.3f MHz ",freq);
        LCD_PrintString(resultStr);
		}
	else if(Menu==2){// Sweep
		Timer_1_WritePeriod(6);//unhörbar
		Vmin=9999;
		Vmax=1;
		for(i=0;i<15;i++){
			SetFrequency(freq+(i-7)*sweepstep);
			CyDelay(2);
			ComputePower_SWR(0,0);
			loga=0;
			if(VSWR>=1){
				if(VSWR>=Vmax) Vmax=VSWR;//max/min Werte ermitteln
				if(VSWR<=Vmin) Vmin=VSWR;	
				//loga=log(VSWR);//Bargraph anzeigen
				loga=log10(VSWR);//Bargraph anzeigen
			}
			if(loga<0) loga=0;
			LCD_DrawVerticalBG(3, i+5, 3, (uint8)(loga*67)+1);
			
			//LCD_DrawVerticalBG(3, i+5, 3, (uint8)(loga*200)+1);
			//LCD_DrawVerticalBG(3, i+5, 3, (uint8)(1+(VSWR-1)*8));
			if(i==14){			
				normieren=0;
				faktor=Vmax-Vmin;
				if (faktor<=0) faktor=1;
				faktor=24/faktor;		
			}
		}	
		LCD_Position(1, 0);
		if(Vmax>100){
			LCD_PrintString("--- ");
			LCD_Position(3u, 0u);
			LCD_PrintString("--- ");
			}
		else{
			if(Vmax>10)
				sprintf((char*)resultStr,"%1.0f ",Vmax);
			else
				sprintf((char*)resultStr,"%1.2f ",Vmax);
			
	        LCD_PrintString(resultStr);
			if(Vmin>10)
				sprintf((char*)resultStr,"%1.0f ",Vmin);
			else
				sprintf((char*)resultStr,"%1.2f ",Vmin);
			Vmin=9999;
			Vmax=1;
			LCD_Position(3u, 0u);
		    LCD_PrintString(resultStr);
		}
		sprintf((char*)resultStr,"% 1.2f ",freq-7*sweepstep);
		LCD_Position(0u, 4u);
        LCD_PrintString(resultStr);
		sprintf((char*)resultStr,"% 1.3f ",freq);
		LCD_Position(0u, 9u);
        LCD_PrintString(resultStr);
		LCD_Position(0u, 15u);
		if(freq>9.99)
		sprintf((char*)resultStr,"% 1.1f ",freq+7*sweepstep);
		else sprintf((char*)resultStr,"% 1.2f ",freq+7*sweepstep);
		LCD_PrintString(resultStr);
		SetFrequency(freq);
		count++;
		if(count==40){//Aufräumen und neu beginnen
			count=0;
			for(i=0;i<20;i++){
				ring2[i]=ring3[i]=0;
			}
			startup=1;
			Vmax=Vmin=0;
			MenuOld=0;
			Menu=2;
			peak1=peak2=0;			
			Nullwert=0;
 			RefWert=1023;
			loop1=0;
 			power=powerPeak=powerRefl=powerReflPeak=0;
		
		
		
		}
	}
		
	else if (Menu==0){
		LCD_Position(1u, 0u);
	    LCD_PrintString("fwd ");
	    LCD_Position(2u, 0u);
	    LCD_PrintString("rev ");
	    LCD_Position(3u, 0u);
	    LCD_PrintString("SWR ");
		AMux_1_Select(3);//Nullpotential
    	ADC_DelSig_1_StartConvert();
        LCD_Position(0u,10u);
		while(!ADC_DelSig_1_IsEndConversion(ADC_DelSig_1_RETURN_STATUS))
		{}
		ADC_DelSig_1_StopConvert();
        output = ADC_DelSig_1_GetResult32();
		quer0=(9*quer0+output)/10;//Messwerte glätten
		//if(loop1>5)
		if(startup==1) Nullwert=output;
		else Nullwert=quer0;
		//float1=ADC_DelSig_1_CountsTo_Volts(Nullwert);
		//float1=(long)(wert1);
		//sprintf((char*)resultStr,"% 1.3f   ",float1);
        //LCD_PrintString(resultStr);
		
        AMux_1_Select(0);//Referenzspannung 1,024V
    	ADC_DelSig_1_StartConvert();
        LCD_Position(0u,3u);
		while(!ADC_DelSig_1_IsEndConversion(ADC_DelSig_1_RETURN_STATUS))
		{}
		ADC_DelSig_1_StopConvert();
        output = ADC_DelSig_1_GetResult32()-Nullwert;
		if(startup==1) quer1=output;
		else quer1=(9*quer1+output)/10;//Messwerte glätten
		wert1=ADC_DelSig_1_CountsTo_mVolts(quer1);
		RefWert=wert1;
		Ref1024=wert1/1023;
		float1=(long)(wert1);
		//float11=(float)(float1);
		//sprintf((char*)resultStr,"% 1.0f  ",float11);
        //LCD_PrintString(resultStr);
		//***********************************************************************
		ComputePower_SWR(1,1);//VSWR berechnen, mit hor. Balkengrafik
		if((power>0.001)&&(VSWR<50)){
			sprintf((char*)resultStr,"% 1.2f ",VSWR);
	        LCD_PrintString(resultStr);
			if(VSWR>1.2){
				Timer_1_WritePeriod((VSWR-1)*8000);
			}
			else{
				Timer_1_WritePeriod(6);//unhörbar
			}
		}
		else{
			LCD_PrintString(" ---   ");
			Timer_1_WritePeriod(6);//unhörbar
		}
		LCD_Position(03,9u);
		sprintf((char*)resultStr,"% 1.3f MHz ",freq);
        LCD_PrintString(resultStr);
		
		loop1++;
		if(loop1==20) {
			loop1=0;
			startup=0;
		  }
		}//Ende Menu0
    }
}


/* [] END OF FILE */
